@@ -197,6 +197,8 @@ function _main()
                 'entry'=>       '記事閲覧',
                 'list'=>        '日記一覧',
                 'post'=>        '日記記事投稿',
+                'upload'=>      '画像投稿',
+                'wysiwyg'=>     '日記記事投稿',
             ),
             'edit'=>        array(      // 各種編集
                 'community'=>   '参加コミュニティ一覧',
