@@ -179,6 +179,18 @@ class webapp extends WAP_private
         $this->ref_diary = $result['id'];
     }
 
+    /**
+     * 本文のフォーマット
+     *
+     * @access public
+     * @param string $value
+     * @return string
+     */
+    function format_body($string)
+    {
+        return strip_tags($string);
+    }
+
     /**
      * データ操作設定・実行
      *
@@ -199,6 +211,11 @@ class webapp extends WAP_private
         $this->objmnp->setValue('modify', date('Y-m-d H:i:s'));
         $this->objmnp->setValue('ref_diary', $this->ref_diary);
         $this->objmnp->setValue('visibility', VISIBILITY_PROTECTED);
+        $this->objmnp->setValue('format', DIARY_FORMAT_PLAIN);
+
+        /* 入力データの加工設定 */
+        $func = array('webapp', 'format_body');
+        $this->objmnp->setInputEffect('body', array('func'=>$func, 'key'=>'body'));
 
         // 更新しない項目名
         $skip = array(
