@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/01/29] 日記のフォーマット定義を追加
  -      [2007/01/08] PathInfo未使用時用のFormメソッドの定義を追加
  -      [2006/09/29] タイムアウト時間設定 WAP_TIME_LIMIT を追加
  -      [2006/09/21] .htaccess、PathInfoに依存しない処理を追加
@@ -323,6 +324,11 @@ define('POSITION_SPONSOR_HEAD',   1);                               // ヘッダ
 define('POSITION_SPONSOR_MIDDLE', 2);                               // 中央部位
 define('POSITION_SPONSOR_SIDE',   3);                               // 側面部位
 
+/* ---------------------------------------- */
+/* 日記のフォーマット */
+define('DIARY_FORMAT_PLAIN', 1);                                    // デフォルト
+define('DIARY_FORMAT_HTML',  2);                                    // HTML形式
+
 /* ---------------------------------------- */
 /* RKTフレームワーク用定義 */
 define('RKT_SEED',WAP_PASS_SEED);                                   // 暗号等に使われる種
