@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
 --      [2007/01/21] お友達の招待名簿を追加
 --      [2006/09/17] 印刷用テーブルの追加
@@ -621,6 +622,23 @@ CREATE TABLE `sns_fri_message` (
   PRIMARY KEY  (`id`)
 ) TYPE=MyISAM AUTO_INCREMENT=1;
 
+-- 
+-- メッセージの添付画像
+-- 
+CREATE TABLE `sns_fri_picture` (
+  `id` int(11) unsigned NOT NULL auto_increment,
+  `modify` timestamp NOT NULL,
+  `ref_account` int(11) NOT NULL,
+  `ref_message` int(11),
+  `title` varchar(255),
+  `filename` varchar(255),
+  `width` int(11),
+  `height` int(11),
+  `thumbnail` varchar(255),
+  `t_width` int(11),
+  `t_height` int(11),
+  PRIMARY KEY  (`id`)
+) TYPE=MyISAM AUTO_INCREMENT=1;
 
 -- --------------------------------------------------------
 -- 
