@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
 --      [2007/01/21] お友達の招待名簿を追加
 --      [2006/12/17] 作成
@@ -657,6 +658,24 @@ CREATE TABLE sns_fri_message (
   PRIMARY KEY  (id)
 );
 
+-- 
+-- メッセージの添付画像
+-- 
+CREATE SEQUENCE seq_sns_fri_picture start 1 increment 1 maxvalue 9223372036854775807 minvalue 1 cache 1;
+CREATE TABLE sns_fri_picture (
+  id integer DEFAULT nextval('seq_sns_fri_picture'::text) NOT NULL,
+  modify timestamp without time zone NOT NULL,
+  ref_account integer NOT NULL,
+  ref_message integer,
+  title varchar(255),
+  filename varchar(255),
+  width integer,
+  height integer,
+  thumbnail varchar(255),
+  t_width integer,
+  t_height integer,
+  PRIMARY KEY  (id)
+);
 
 -- --------------------------------------------------------
 -- 
