@@ -20,6 +20,7 @@
 --      yujiro@rakuto.net
 --      http://rakuto.net/rktSNS/
 -- 更新履歴：
+--      [2007/01/30] メッセージの添付画像(sns_fri_picture)を追加
 --      [2007/01/21] お友達のお友達名簿を修正
 --      [2007/01/21] お友達の招待名簿を追加
 --      [2006/09/17] インデックスの記述を消去
@@ -605,6 +606,23 @@ CREATE TABLE 'sns_fri_message' (
   PRIMARY KEY  ('id')
 );
 
+-- 
+-- メッセージの添付画像
+-- 
+CREATE TABLE 'sns_fri_picture' (
+  'id' integer NOT NULL,
+  'modify' timestamp NOT NULL,
+  'ref_account' integer NOT NULL,
+  'ref_message' integer,
+  'title' varchar(255),
+  'filename' varchar(255),
+  'width' integer,
+  'height' integer,
+  'thumbnail' varchar(255),
+  't_width' integer,
+  't_height' integer,
+  PRIMARY KEY  ('id')
+);
 
 -- --------------------------------------------------------
 -- 
